@@ -48,9 +48,10 @@ config.buildInfo = {
 
 config.rendererAvailable = true;
 
-jest.mock('app/core/core', () => {
+jest.mock('app/core/services/context_srv', () => {
   return {
     contextSrv: {
+      ...jest.requireActual('app/core/services/context_srv').contextSrv,
       hasPermission: () => true,
     },
   };
